@@ -1,3 +1,6 @@
+import django
+django.setup()
+
 from .django_helpers.pagination import (
     get_paginator,
     create_paginated_type_mixin
@@ -49,11 +52,13 @@ from .graphql_helpers.schema_helpers import (
 from .graphql_helpers.views import (
     SafeGraphQLView
 )
+
 from .schema_models.geojson import (
     GrapheneFeatureCollection,
     FeatureCollectionDataType, FeatureDataType, FeatureGeometryDataType, feature_data_type_fields,
     feature_geometry_data_type_fields
 )
+
 from .schema_models.group_schema import (
     GroupType,
     UpsertGroup,
@@ -74,9 +79,6 @@ from .schema_models.user_schema import (
     graphql_query_users,
     user_fields,
     user_mutation_config,
-    graphql_authenticate_user,
-    graphql_verify_user,
-    graphql_refresh_token
 )
 from .testcases import (
     client_for_testing
